package main

import (
    "gorm.io/driver/sqlite"
    "gorm.io/gorm"
	"log/slog"
) 

type ArtistProfile struct {
    gorm.Model
    SpotifyID string `gorm:"unique"`
    Name string
    Popularity int
    Genres []Genre `gorm:"many2many:artist_genres;"`
}

type Genre struct {
    gorm.Model
    Name string `gorm:"unique"`
}

func setupTestDatabase(name string) *gorm.DB  {
	slog.Info("[GOMUSIC] Setting up new test database in memory")
	// Open a named DB instance so each test has a clean environment
	db, err := gorm.Open(sqlite.Open("file:test1?mode=memory&cache=shared"), &gorm.Config{})
	if err != nil {
		panic("Failed to open database")
	}

	// Run model migrations here to keep DB consistent
    db.AutoMigrate(&ArtistProfile{}, &Genre{})
	return db
}

func setupDatabase() *gorm.DB  {
	slog.Info("[GOMUSIC] Setting up database and running auto migrations")
	db, err := gorm.Open(sqlite.Open("gomusic.db"), &gorm.Config{})
    if err != nil {
    	panic("Failed to open database")
    }

    // Run model migrations here to keep DB consistent
    db.AutoMigrate(&ArtistProfile{}, &Genre{})
    return db
}
